# ver, rel are passed in from Makefile so we only have to set them one place
Version: 4.1.0
Release: 1

Summary: LSB Core-T2C Test Suite
Vendor: IBM
# name, ver, rel are passed in from Makefile so we only have to set them one place
Name: lsb-test-core-t2c
Source: %{name}-%{version}.src.tgz
License: GPL
URL: http://www.linux-foundation.org/en/Downloads
Group: Development/Tools
Buildroot: %{_builddir}/%{name}-root
AutoReqProv: no
Requires: lsb >= 3.1, lsb-tet3-lite >= 3.7
BuildRequires: lsb-tet3-lite-devel, lsb-build-cc

%description
The test suite for libc created using the T2C 
("Template-to-C") framework.

%prep
if [ ! -x /opt/lsb/bin/lsbc++ ] ; then
    printf "lsbc++ not found, required for compilation, aborting\n"
    exit 1
fi

%setup -q

%build
# build T2C framework components first
chmod -R +rx .
CUR_DIR=`pwd`
export T2C_ROOT="${CUR_DIR}/t2c_framework" 
export LSBCC_BESTEFFORT=1
t2c_framework/t2c/build.sh > build.log
cd runtime-t2c 
./build_all.sh 

%install

#install the test suites
T2C_ROOT=${RPM_BUILD_ROOT}/opt/lsb/test/core-t2c
rm -rf ${T2C_ROOT}
rm -rf ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}
mkdir -p ${T2C_ROOT}
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}

cd runtime-t2c
for TEST_SUITE in "*-t2c"
do 
    cp -r ${TEST_SUITE} ${T2C_ROOT}
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/src ${T2C_ROOT}/${TEST_SUITE}/gen_tests ${T2C_ROOT}/${TEST_SUITE}/clean ${T2C_ROOT}/${TEST_SUITE}/*.cfg
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/testdata/testdata_src
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/tests/Makefile ${T2C_ROOT}/${TEST_SUITE}/tests/*.mk
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/tests/*/Makefile
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/tests/*/*.c
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/include
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/doc
done
cd ..

install -d ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}
cp runtime-t2c/LICENSE ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}
cp runtime-t2c/run_tests.sh runtime-t2c/tet_code runtime-t2c/tet_scen runtime-t2c/tetexec.cfg ${T2C_ROOT}

%files
%defattr(777,tester,tester)
/opt/lsb/test/core-t2c
%dir /opt/lsb/doc/%{name}
/opt/lsb/doc/%{name}/*

%pre
PATH=/usr/sbin:$PATH

# Create a new user ('tester') if it doesn't exist.
echo
echo "Checking if there is a user named 'tester' on this system..."
id tester >/dev/null 2>&1

if [ $? -ne 0 ]; then 
    echo "User 'tester' does not exist. Attempting to create it...".
    useradd -d /home/tester -s /bin/sh -c "core-t2c tester login" tester -m >/dev/null 2>&1
    
    if [ $? = 0 ]; then
        echo "User 'tester' was created successfully."
        echo "If you later want to delete this user account, run the following command (as root):"
        echo "    userdel -rf tester"
        echo "Here 'userdel' is assumed to be somewhere in your path"
    else
        echo "Failed to add user 'tester'."
        echo "To be able to run the tests you should add this user manually."
        exit 1
    fi
fi

# Create 'tester' group and make 'tester' its member
echo
echo "Attempting to create group 'tester'"
groupadd tester >/dev/null 2>&1

if [ $? = 0 ]; then
# This message is output only if the group did not exist before and 
# now it was created successfully.
	echo "If you later want to delete this group, run the following command (as root):"
	echo "    groupdel tester"
fi

usermod -G tester tester >/dev/null 2>&1

# End of the preinstall script.

%post

RESULT=0

# print out a message
echo
echo "LSB core-t2c Test Suite has been installed to"
echo "/opt/lsb/test/core-t2c."
if [ $RESULT -ne 0 ]; then
    echo
    echo "There were warnings."
fi

# End of the postinstall script.

%preun
rm -rf /opt/lsb/test/core-t2c/results
rm -rf /opt/lsb/test/core-t2c/tet_tmp_dir

# End of the preuninstall script.

%clean
if [ ! -z "${RPM_BUILD_ROOT}"  -a "${RPM_BUILD_ROOT}" != "/" ]; then
    rm -rf ${RPM_BUILD_ROOT}
fi
